{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Fourier analyze the original and the compressed & decompressed signals"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/usr/local/lib/python2.7/site-packages/matplotlib/font_manager.py:273: UserWarning: Matplotlib is building the font cache using fc-list. This may take a moment.\n",
      "  warnings.warn('Matplotlib is building the font cache using fc-list. This may take a moment.')\n"
     ]
    }
   ],
   "source": [
    "%matplotlib inline\n",
    "import numpy as np\n",
    "import matplotlib.pyplot as plt\n",
    "plt.rcParams['figure.figsize'] = (7,5)\n",
    "import itertools as it\n",
    "import scipy.signal"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "import wave\n",
    "import struct"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "class FourierAnalysis:\n",
    "\n",
    "    def __init__(self, input_filename):\n",
    "        self.input_filename = input_filename\n",
    "        self.input_file = wave.open(self.input_filename, 'r')\n",
    "        self.params = self.input_file.getparams()\n",
    "        nframes = self.input_file.getnframes()\n",
    "        self.input_data = np.empty(nframes)\n",
    "        for f in range(nframes):\n",
    "            amplitude = self.input_file.readframes(1)\n",
    "            self.input_data[f] = struct.unpack('=h', amplitude)[0]\n",
    "        \n",
    "    def define_analysis_params(self, window_size=320, window_displacement=160):\n",
    "        self.window_size = window_size\n",
    "        self.window_displacement = window_displacement\n",
    "        self.num_windows = self.input_file.getnframes() / self.window_displacement - 1\n",
    "        \n",
    "        self.fourier_amplitudes = np.empty((self.num_windows, self.window_size))\n",
    "        \n",
    "    def get_hann_times_window(self, window_number):\n",
    "        start_window = self.window_displacement * window_number\n",
    "        end_window = start_window + self.window_size\n",
    "        return scipy.signal.hann(self.window_size) * self.input_data[start_window:end_window]\n",
    "    \n",
    "    def fourier_signal(self):\n",
    "        for window_number in range(self.num_windows):\n",
    "            self.fourier_amplitudes[window_number] = abs(self.fourier_window(window_number))\n",
    "    \n",
    "    def fourier_window(self, window_number):\n",
    "        return np.fft.fft(self.get_hann_times_window(window_number))\n",
    "    \n",
    "    def close_output(self):\n",
    "        self.output_file.close()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "filename = 'demo'"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "my_FA = FourierAnalysis('wav_examples/{}.wav'.format(filename))\n",
    "my_FA.define_analysis_params()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "my_FA.fourier_signal()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "<matplotlib.image.AxesImage at 0x10f692f10>"
      ]
     },
     "execution_count": 17,
     "metadata": {},
     "output_type": "execute_result"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAmsAAAHHCAYAAADgeh/sAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nAABJRU5ErkJggg==\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x10f692a90>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "plt.ylim(0, my_FA.window_size / 2)\n",
    "plt.xlabel('Window number')\n",
    "plt.ylabel('Frequencies')\n",
    "plt.imshow(my_FA.fourier_amplitudes.transpose(), cmap=plt.cm.hot, aspect='auto',\n",
    "          interpolation='None')\n",
    "#plt.savefig('plots/fourier_{}.eps'.format(filename), bbox_inches='tight')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 18,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "<matplotlib.image.AxesImage at 0x10f6ab510>"
      ]
     },
     "execution_count": 18,
     "metadata": {},
     "output_type": "execute_result"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAmsAAAHHCAYAAADgeh/sAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x10f6a3090>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "my_FA_output = FourierAnalysis('wav_examples/{}_output.wav'.format(filename))\n",
    "my_FA_output.define_analysis_params()\n",
    "my_FA_output.fourier_signal()\n",
    "plt.ylim(0, my_FA.window_size / 2)\n",
    "plt.xlabel('Window number')\n",
    "plt.ylabel('Frequencies')\n",
    "plt.imshow(my_FA_output.fourier_amplitudes.transpose(), cmap=plt.cm.hot, aspect='auto',\n",
    "          interpolation='None')\n",
    "#plt.savefig('plots/fourier_{}_output.eps'.format(filename), bbox_inches='tight')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 2",
   "language": "python",
   "name": "python2"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 2
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython2",
   "version": "2.7.11"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
